==> c2cgeoportal-2.1.0.dev5-py2.py3-none-any.whl: c2cgeoportal/scripts/gen_version.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2016, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.

import os
import re
import subprocess


def _get_versions():
    version = subprocess.check_output(["python", "./setup.py", "--version"]).strip()
    git_hash = subprocess.check_output(["git", "rev-parse", "HEAD"]).strip()
    try:
        with open(os.devnull, "w") as devnull:
            git_tag = subprocess.check_output(["git", "describe", "--tags", "--first-parent"],
                                              stderr=devnull).strip()
        git_tag = re.sub(r"-g[a-f0-9]+$", "", git_tag)
    except:
        git_tag = None
    return {
        "version": version,
        "git_hash": git_hash,
        "git_tag": git_tag
    }


def main():
    print "INFO = {"
    for key, value in _get_versions().iteritems():
        print "    \"%s\": \"%s\"," % (key, str(value).replace("\\", "\\\\").replace("\"", "\\\""))
    print "}"


if __name__ == "__main__":
    main()

==> c2cgeoportal-2.2.0.dev9-py2.py3-none-any.whl: c2cgeoportal/scripts/gen_version.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2016-2017, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.

import os
import re
import subprocess


def _get_versions():
    version = subprocess.check_output(["python", "./setup.py", "--version"]).strip()
    git_hash = subprocess.check_output(["git", "rev-parse", "HEAD"]).strip()
    try:
        with open(os.devnull, "w") as devnull:
            git_tag = subprocess.check_output(["git", "describe", "--tags", "--first-parent"],
                                              stderr=devnull).strip()
        git_tag = re.sub(r"-g[a-f0-9]+$", "", git_tag)
    except:
        git_tag = None
    return {
        "version": version,
        "git_hash": git_hash,
        "git_tag": git_tag
    }


def main():
    print "INFO = {"
    for key, value in _get_versions().iteritems():
        print "    \"{0!s}\": \"{1!s}\",".format(key, str(value).replace("\\", "\\\\").replace("\"", "\\\""))
    print "}"


if __name__ == "__main__":
    main()
